@@ -17,7 +17,7 @@ Usage::
 
     list_playback_configurations_paginator: ListPlaybackConfigurationsPaginator = client.get_paginator("list_playback_configurations")
 """
-from mypy_boto3_mediatailor.client import MediaTailorClient, MediaTailorClient as Client
+from mypy_boto3_mediatailor.client import MediaTailorClient as Client, MediaTailorClient
 from mypy_boto3_mediatailor.paginator import ListPlaybackConfigurationsPaginator
 
 
